@@ -1,8 +1,8 @@
 import requests
 import json
 
-from pysecretserver.query import Request
 from pysecretserver.items import Secrets, Folders, Metadata
+from pysecretserver.query import Request
 
 class Api(object):
     """ The API object is the point of entry to pysecretserver.
@@ -42,5 +42,5 @@ class Api(object):
         self.token = req.get_session_token({
             'username': self.username,
             'password': self.password,
-            'grant_type': 'password'
+            'grant_type': self.grant_type
         })
