@@ -41,12 +41,21 @@ class Item(object):
         
         return self.request.delete_item(self.item_plural_name, item_id)
     
-    def get_item_metadata(self, item_id):
+    def get_item_metadata(self, item_id, meta_field_id=None):
         
-        return self.request.search_item(
-            'metadata',
-            {'filter.itemId': item_id, 'filter.metadataType': self.item_name}
-        )  ['records']  
+        filters = {
+            'filter.itemId': item_id,
+            'filter.metadataType': self.item_name
+        }
+        if meta_field_id:
+            filters = {
+                **filters,
+                **{
+                    'filter.metadataFieldId': meta_field_id
+                }
+            }
+
+        return self.request.search_item('metadata', filters)['records']  
 
     def create_item_metadata(self, item_id, data={}):
         
