@@ -72,10 +72,6 @@ class Request(object):
         self.url = self.base + "api/v1"
         self.auth_url = self.base + 'oauth2/token'
 
-    def post(self, data):
-
-        return self._make_request(verb="post", data=data)
-
     def _make_request(self, verb="get", endpoint=None, data=None):
 
         if verb in ("post", "put"):
@@ -117,7 +113,8 @@ class Request(object):
             raise RequestError(resp)
 
     def normalize_url(self, url):
-        """ Builds a url for POST actions.
+        """
+        Builds a url for POST actions.
         """
         if url[-1] != "/":
             return "{}/".format(url)
@@ -128,11 +125,6 @@ class Request(object):
 
         return self._make_request(verb='get', endpoint=f"/{item}/{item_id}")
 
-    def get_item_metadata(self, item, item_id, data):
-
-        query = urllib.parse.urlencode(data, doseq=False)
-        return self._make_request(verb="get", endpoint=f"/{item}/?{query}")
-
     def search_item(self, item, data):
 
         query = urllib.parse.urlencode(data, doseq=False)
@@ -159,6 +151,11 @@ class Request(object):
 
         return self._make_request(verb="delete", endpoint=f"/{item}/{item_id}")
 
+    def get_item_metadata(self, item, item_id, data):
+
+        query = urllib.parse.urlencode(data, doseq=False)
+        return self._make_request(verb="get", endpoint=f"/{item}/?{query}")
+    
     def create_item_metadata(self, item, item_id, data={}):
         
         return self._make_request(verb="post", endpoint=f"/metadata/{item}/{item_id}", data=data)
@@ -169,4 +166,4 @@ class Request(object):
     
     def delete_item_metadata(self, item, item_id, meta_id):
         
-        return self._make_request(verb="delete", endpoint=f"/metadata/{item}/{item_id}/{meta_id}")
\ No newline at end of file
+        return self._make_request(verb="delete", endpoint=f"/metadata/{item}/{item_id}/{meta_id}")
